# WhereDoIHaveAnAccount Third Party Dependencies

WhereDoIHaveAnAccount depends on third party libraries to implement some functionality. This document describes which libraries WDIHAA depends on. This is a best effort attempt to describe the library's dependencies, it is subject to change as libraries are added/removed.

| Name            | URL                                                | License                |
|-----------------|----------------------------------------------------|------------------------|
| pytest          | https://github.com/pytest-dev/pytest               | MIT license            |
| tox             | https://github.com/tox-dev/tox                     | MIT license            |
| imap-tools      | https://github.com/ikvk/imap_tools                 | Apache-2.0 license     |
| requests        | https://github.com/psf/requests                    | Apache-2.0 license     |
| email-validator | https://github.com/JoshData/python-email-validator | CC0-1.0 license        |
| pytest-cov      | https://github.com/pytest-dev/pytest-cov           | MIT license            |
| pandas          | https://github.com/pandas-dev/pandas               | BSD-3-Clause license   |
| feather-format  | https://github.com/wesm/feather                    | Apache-2.0 license     |
| nltk            | https://github.com/nltk/nltk                       | Apache-2.0 license     |
| scikit-learn    | https://github.com/scikit-learn/scikit-learn       | BSD-3-Clause license   |